@@ -40,7 +40,7 @@ use core::fmt::Debug;
 use messenger::Messenger;
 use raw_window_handle::{HasRawDisplayHandle, HasRawWindowHandle};
 use rio_backend::config::{
-    colors::{term::List, ColorWGPU},
+    colors::term::List,
     renderer::{Backend as RendererBackend, Performance as RendererPerformance},
 };
 use rio_backend::sugarloaf::{
@@ -172,7 +172,7 @@ impl Screen {
             backend,
         };
 
-        let sugarloaf: Sugarloaf = match Sugarloaf::new(
+        let mut sugarloaf: Sugarloaf = match Sugarloaf::new(
             &sugarloaf_window,
             sugarloaf_renderer,
             config.fonts.to_owned(),
@@ -197,6 +197,13 @@ impl Screen {
             config.navigation.has_navigation_key_bindings(),
             config.keyboard,
         );
+
+        sugarloaf.set_background_color(state.dynamic_background);
+
+        if let Some(image) = &config.window.background_image {
+            sugarloaf.set_background_image(image);
+        }
+
         let ime = Ime::new();
 
         let is_collapsed = config.navigation.is_collapsed_mode();
@@ -224,6 +231,7 @@ impl Screen {
             sugarloaf_errors,
         )?;
 
+        sugarloaf.render();
         Ok(Screen {
             mouse_bindings: bindings::default_mouse_bindings(),
             modifiers: Modifiers::default(),
@@ -343,7 +351,7 @@ impl Screen {
             bg_color.a = config.window.background_opacity as f64;
         }
 
-        self.init(bg_color, &config.window.background_image);
+        self.init();
     }
 
     #[inline]
@@ -1198,18 +1206,9 @@ impl Screen {
     }
 
     #[inline]
-    pub fn init(
-        &mut self,
-        color: ColorWGPU,
-        background_image: &Option<sugarloaf::core::ImageProperties>,
-    ) {
+    pub fn init(&mut self) {
         let initial_columns = self.sugarloaf.layout.columns;
 
-        self.sugarloaf.set_background_color(color);
-        if let Some(image) = background_image {
-            self.sugarloaf.set_background_image(image);
-        }
-
         self.sugarloaf.calculate_bounds();
 
         if self.sugarloaf.layout.columns != initial_columns {
